@@ -368,8 +368,10 @@ int check_format_string(char *fmt, int format_arg)
             switch (*c)
             {
                 case 's':
+		  if(get_argument(arg)) {
                     if (!get_argument(arg)->is_constant)
                         return 1;
+		  }
                     /* FALL THROUGH */
 
                 case 'c':
@@ -853,6 +855,8 @@ void determine_language(char *filename, FILE *fd, int forcelang)
             setup_c(fd);
         else if (forcelang == LANG_PERL)
             setup_perl(fd);
+	else if ( forcelang == LANG_PHP)
+	  setup_php(fd);
         return;
     }
     if (!dot)
