@@ -152,7 +152,6 @@ void log_vulnerability(type_t type, Severity_t severity)
 
 void log_perlbacktick(int lineno, Severity_t severity)
 {
-
     vulnerability_t *   log;
 
     log = (vulnerability_t *)malloc(sizeof(vulnerability_t));
@@ -164,13 +163,11 @@ void log_perlbacktick(int lineno, Severity_t severity)
     log->uses     = (toctou_use_t *)NULL;
 
     insert_vulnerability(log);
-
 }
 
 
 void log_phpbacktick(int lineno, Severity_t severity)
 {
-
     vulnerability_t *   log;
 
     log = (vulnerability_t *)malloc(sizeof(vulnerability_t));
@@ -182,12 +179,10 @@ void log_phpbacktick(int lineno, Severity_t severity)
     log->uses     = (toctou_use_t *)NULL;
 
     insert_vulnerability(log);
-
 }
 
 void log_pythonbacktick(int lineno, Severity_t severity)
 {
-
     vulnerability_t *   log;
 
     log = (vulnerability_t *)malloc(sizeof(vulnerability_t));
@@ -199,8 +194,8 @@ void log_pythonbacktick(int lineno, Severity_t severity)
     log->uses     = (toctou_use_t *)NULL;
 
     insert_vulnerability(log);
-
 }
+
 void log_staticbuffer(type_t type, int lineno, Severity_t severity)
 {
     vulnerability_t *   log;
@@ -273,15 +268,15 @@ void report_vulnerability(vulnerability_t *ptr)
             if (ptr->data->BOProblem->FormatArg > 0)
             {
                 printf("Check to be sure that the format string passed as argument %d to this function\n", ptr->data->BOProblem->FormatArg);
-                printf("call doest not come from an untrusted source that could have added formatting\n");
+                printf("call does not come from an untrusted source that could have added formatting\n");
                 printf("characters that the code is not prepared to handle.  Additionally, the format\n");
                 printf("string could contain `%%s' without precision that could result in a buffer\n");
                 printf("overflow.\n");
             }
             if (ptr->data->BOProblem->SrcBufArg > 0)
             {
-                printf("Check to be sure that argument %d passed to this function call will not more\n", ptr->data->BOProblem->SrcBufArg);
-                printf("data than can be handled, resulting in a buffer overflow.\n");
+                printf("Check to be sure that argument %d passed to this function call will not copy\n", ptr->data->BOProblem->SrcBufArg);
+                printf("more data than can be handled, resulting in a buffer overflow.\n");
             }
             printf("\n");
             break;
@@ -411,6 +406,7 @@ void generate_report(void)
     ignore_t *          inext;
     vulnerability_t *   ptr;
     vulnerability_t *   next;
+
     for (ptr = list_head;  ptr != (vulnerability_t *)NULL;  ptr = ptr->next)
     {
         if (ptr->severity == Default || ptr->severity >= warning_level)
