@@ -190,7 +190,9 @@ void StartElement(void *udata, const char *name, const char **atts)
                 count++;
             }
         }
-        if (!HashGet(mydata->parenthash, langname))
+	/* This prevented loading multiple xml files for the same language */
+/*  	if (!HashGet(mydata->parenthash, langname)) */
+	if(!(mydata->myhash=HashGet(mydata->parenthash,langname)))
         {
             mydata->myhash = HashInit();
             if (mydata->myhash != (Hash)NULL)
